# RAGchain

RAGchain is framework focused on RAG (Retrieval Augmented Generation) workflow compatible with langchain.
RAGchain supports advanced RAG workflow like reranker, various retrievers, OCR, and so on. 
With RAGchain, you can build complex RAG workflow easily.

API spec at [here](https://nomadamas.github.io/KoPrivateGPT).

# Installation
## From pip

simply run below. (We are not deployed yet.)

```bash
pip install RAGchain
```

## From source
First, clone this git repository to your local machine.

```bash
git clone https://github.com/NomaDamas/RAGchain.git
cd RAGchain
```

Then, install RAGchain module.
```bash
python3 setup.py develop
```

For using files at root folder and test, run dev requirements.
```bash
pip install dev_requirements.txt
```

## Acknowledgement

